===================
cw-EPR spectroscopy
===================

What follows is a rather hands-on introduction to recording, processing and analysing cw-EPR spectra. Don't expect any details about the physics behind EPR spectroscopy. For this, the reader is referred to the body of excellent EPR literature (for a selection, see below).


.. important::
    The following is in no way meant to replace reading good books about EPR spectroscopy and to get a proper in-person training from experienced spectroscopists in the lab. However, as good hands-on EPR books are rare (and particularly their existence in EPR labs), as is good in-person training, the following content may be useful for some people. Nevertheless, there is no guarantee of the information provided here to be accurate or applicable to your specific situation. Use entirely on your own risk.


Some people claim cw-EPR spectroscopy to be outdated and superseded by the (in any single respect) much superior pulsed methods. The authors carefully disagree with this notion. cw-EPR spectroscopy clearly still has its standing on its own, and there are quite a few areas where pulsed methods cannot be used to get the same information, at least not with similar ease.

On the other hand, while cw-EPR spectroscopy is regarded as "simple" method, even properly recording spectra is not as easy as it may look like at first. There are simply too many parameters to take care of not to (frequently) forget something if not operating the spectrometer on a daily basis (and having got appropriate training). Besides that, as usual, the devil is in the details.

There are a number of aspects covered in this cw-EPR spectroscopy primer, as can be seen from the table of contents. One key idea is that recording cw-EPR spectra, however complicated in detail this may be, can be mostly automated and formalised. The central aspect of spectroscopy is *not* recording and accumulating raw data, but processing and analysing these data.

Of course, processing and analysis are described with particular focus on the cwepr package. However, there should be a lot of information there that is of more general use. After all, the cwepr package is developed and maintained by people actively working in the field.


Selected bibliography
=====================

The following bibliography is by no means exhaustive. General aspects of EPR spectroscopy are covered in :cite:t:`carrington-a-1967,atherton-n-1993,weil-ja-2007,brustolon-m-2009,chechik-v-2016,goldfarb-d-2018` and more theoretical aspects in :cite:t:`abragam-a-1961,poole-cp-1987,slichter-cp-1963`. Perhaps the best introduction into practical aspects of cw-EPR spectroscopy is :cite:t:`eaton-ge-2010`.

.. bibliography::

